==> freediams_0.4.2.orig.tar.gz: freediams-0.4.2/global_resources/translations/templatesplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Templates::Internal::TemplatesContentEditor</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatescontenteditor.ui" line="14"/>
        <location filename="../../plugins/templatesplugin/templatescontenteditor.ui" line="26"/>
        <source>Content editor</source>
        <translation>Éditeur du contenu</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesCoreListener</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="124"/>
        <source>Save templates .</source>
        <translation>Sauvegarder les modèles.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="125"/>
        <source>Some datas are not actually saved into database.Do you want to save them ?
 Answering &apos;No&apos; will cause definitive data lose.</source>
        <translation>Certaines données ne sont pas encore sauvegardées dans la base de données. Voulez-vous les sauvegarder ?
Répondre &apos;Non&apos; causera une perte de données définitive.</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesCreationDialog</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="26"/>
        <source>Template creation</source>
        <translation>Création de modèle</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="43"/>
        <source>User owner</source>
        <translation>Utilisateur propriétaire</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="57"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="67"/>
        <source>Parent category</source>
        <translation>Dans la catégorie</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="77"/>
        <source>Summary</source>
        <translation>Résumé</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="89"/>
        <source>View content</source>
        <translation>Voir le contenu</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesEditDialog</name>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="14"/>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="26"/>
        <source>Template edition</source>
        <translation>Éditeur de modèle</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="43"/>
        <source>User owner</source>
        <translation>Utilisateur propriétaire</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="50"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="57"/>
        <source>Parent category</source>
        <translation>Dans la catégorie</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="64"/>
        <source>Summary</source>
        <translation>Résumé</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="76"/>
        <source>View content</source>
        <translation>Voir le contenu</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesPreferencesWidget</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="43"/>
        <source>Data saving</source>
        <translation>Sauvegarde des données</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="49"/>
        <source>Always ask for confirmation before deletion</source>
        <translation>Toujours demander une confirmation avant la suppression</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="59"/>
        <source>Presentation</source>
        <translation>Présentation</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="67"/>
        <source>Font</source>
        <translation>Police de caractères</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="82"/>
        <source>Always expand categories and templates tree</source>
        <translation>Toujours développer les branches de l&apos;arbre des modèles</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="96"/>
        <source>Category background color</source>
        <translation>Couleur de fond des catégories</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="122"/>
        <source>Category foreground color</source>
        <translation>Couleur de la police des catégories</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="174"/>
        <source>Template foreground color</source>
        <translation>Couleur de fond des modèles</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="148"/>
        <source>Template background color</source>
        <translation>Couleur de la police des modèles</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="14"/>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="26"/>
        <source>Templates preferences</source>
        <translation>Préférences des modèles</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="89"/>
        <source>Lock category view at startup</source>
        <translation>Vérouiller la vue au démarrage</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesView</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.ui" line="28"/>
        <source>Categories tree</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Templates::TemplateBase</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="362"/>
        <source>Unable to connect the Templates host.</source>
        <translation>Impossible de se connecter à l&apos;hôte.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="362"/>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="368"/>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="372"/>
        <source>Please contact dev team.</source>
        <translation>Veuillez contacter l&apos;équipe de développement.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="368"/>
        <source>Unable to create the Templates database.</source>
        <translation>Impossible de créer la base de données Modèles.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="372"/>
        <source>Unable to connect the Templates database.</source>
        <translation>Impossible de se connecter à la base de données Modèles.</translation>
    </message>
</context>
<context>
    <name>Templates::TemplatesModel</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="1030"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
</context>
<context>
    <name>Templates::TemplatesView</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="623"/>
        <source>About to delete %1.</source>
        <translation>Sur le point de supprimer %1.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="624"/>
        <source>Do you really want to remove %1 from your templates&apos; list ?</source>
        <translation>Voulez-vous réellement supprimer %1 de votre liste de modèles ?</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="625"/>
        <source>This action is definitive and all informations will be lost. Children of this item will be deleted as well.</source>
        <translation>Cette action est définitive. Toutes les informations de ces modèles seront perdues. Toutes les sous-catégories, s&apos;il en existe, seront effacées aussi.</translation>
    </message>
</context>
</TS>

==> freediams_0.5.4.orig.tar.gz: freediams-0.5.4/global_resources/translations/templatesplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Templates::Internal::TemplatesContentEditor</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatescontenteditor.ui" line="14"/>
        <location filename="../../plugins/templatesplugin/templatescontenteditor.ui" line="26"/>
        <source>Content editor</source>
        <translation>Éditeur du contenu</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesCoreListener</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="110"/>
        <source>Save templates .</source>
        <translation>Sauvegarder les modèles.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="111"/>
        <source>Some datas are not actually saved into database.Do you want to save them ?
 Answering &apos;No&apos; will cause definitive data lose.</source>
        <translation>Certaines données ne sont pas encore sauvegardées dans la base de données. Voulez-vous les sauvegarder ?
Répondre &apos;Non&apos; causera une perte de données définitive.</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesCreationDialog</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="26"/>
        <source>Template creation</source>
        <translation>Création de modèle</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="43"/>
        <source>User owner</source>
        <translation>Utilisateur propriétaire</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="57"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="67"/>
        <source>Parent category</source>
        <translation>Dans la catégorie</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="77"/>
        <source>Summary</source>
        <translation>Résumé</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="89"/>
        <source>View content</source>
        <translation>Voir le contenu</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesEditDialog</name>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="14"/>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="26"/>
        <source>Template edition</source>
        <translation>Éditeur de modèle</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="43"/>
        <source>User owner</source>
        <translation>Utilisateur propriétaire</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="50"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="57"/>
        <source>Parent category</source>
        <translation>Dans la catégorie</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="64"/>
        <source>Summary</source>
        <translation>Résumé</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="76"/>
        <source>View content</source>
        <translation>Voir le contenu</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesPreferencesWidget</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="43"/>
        <source>Data saving</source>
        <translation>Sauvegarde des données</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="49"/>
        <source>Always ask for confirmation before deletion</source>
        <translation>Toujours demander une confirmation avant la suppression</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="59"/>
        <source>Presentation</source>
        <translation>Présentation</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="67"/>
        <source>Font</source>
        <translation>Police de caractères</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="82"/>
        <source>Always expand categories and templates tree</source>
        <translation>Toujours développer les branches de l&apos;arbre des modèles</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="96"/>
        <source>Category background color</source>
        <translation>Couleur de fond des catégories</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="122"/>
        <source>Category foreground color</source>
        <translation>Couleur de la police des catégories</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="174"/>
        <source>Template foreground color</source>
        <translation>Couleur de fond des modèles</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="148"/>
        <source>Template background color</source>
        <translation>Couleur de la police des modèles</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="14"/>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="26"/>
        <source>Templates preferences</source>
        <translation>Préférences des modèles</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="89"/>
        <source>Lock category view at startup</source>
        <translation>Verrouiller la vue au démarrage</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesView</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.ui" line="28"/>
        <source>Categories tree</source>
        <translation>Arborescence des catégories</translation>
    </message>
</context>
<context>
    <name>Templates::TemplateBase</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="353"/>
        <source>Unable to connect the Templates host.</source>
        <translation>Impossible de se connecter à l&apos;hôte.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="353"/>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="359"/>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="363"/>
        <source>Please contact dev team.</source>
        <translation>Veuillez contacter l&apos;équipe de développement.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="359"/>
        <source>Unable to create the Templates database.</source>
        <translation>Impossible de créer la base de données Modèles.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="363"/>
        <source>Unable to connect the Templates database.</source>
        <translation>Impossible de se connecter à la base de données Modèles.</translation>
    </message>
</context>
<context>
    <name>Templates::TemplatesModel</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="1021"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
</context>
<context>
    <name>Templates::TemplatesView</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="610"/>
        <source>About to delete %1.</source>
        <translation>Sur le point de supprimer %1.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="611"/>
        <source>Do you really want to remove %1 from your templates&apos; list ?</source>
        <translation>Voulez-vous réellement supprimer %1 de votre liste de modèles ?</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="612"/>
        <source>This action is definitive and all informations will be lost. Children of this item will be deleted as well.</source>
        <translation>Cette action est définitive. Toutes les informations de ces modèles seront perdues. Toutes les sous-catégories, s&apos;il en existe, seront effacées aussi.</translation>
    </message>
</context>
</TS>
